@@ -3,7 +3,7 @@
 # SDL.pm
 #
 # Copyright (C) 2005 David J. Goehrig <dgoehrig@cpan.org>
-# Copyright (C) 2009 Kartik Thakore   <kthakore@cpan.org>
+# Copyright (C) 2010 Kartik Thakore   <kthakore@cpan.org>
 # ------------------------------------------------------------------------------
 #
 # This library is free software; you can redistribute it and/or
@@ -45,13 +45,14 @@ our @ISA = qw(Exporter DynaLoader);
 
 use base 'Exporter';
 our @EXPORT      = @{ $SDL::Constants::EXPORT_TAGS{SDL} };
+push @EXPORT, 'NULL';
 our %EXPORT_TAGS = (
 	all      => \@EXPORT,
 	init     => $SDL::Constants::EXPORT_TAGS{'SDL/init'},
 	defaults => $SDL::Constants::EXPORT_TAGS{'SDL/defaults'}
 );
 
-our $VERSION = '2.3_9'; #Development Release
+our $VERSION = '2.500_1'; #RC
 $VERSION = eval $VERSION;
 
 print "$VERSION" if (defined($ARGV[0]) && ($ARGV[0] eq '--SDLperl'));
@@ -62,6 +63,26 @@ sub NULL {
 	return 0;
 }
 
+# workaround, doing putenv from perl instead of sdl's:
+#int
+#putenv (variable)
+#	char *variable
+#	CODE:
+#		RETVAL = SDL_putenv(variable);
+#	OUTPUT:
+#		RETVAL
+sub putenv
+{
+	my $cmd  = shift;
+	if($cmd =~ /^(\w+)=(.*)$/)
+	{
+		$ENV{$1} = $2;
+		return 0;
+	}
+	
+	return -1;
+}
+
 # workaround as:
 # extern DECLSPEC void SDLCALL SDL_SetError(const char *fmt, ...);
 sub set_error {
